#! /bin/zsh -f
#.zshrc
# $Id: .zshrc.m4,v 1.48 1996/06/13 17:58:04 gjb Exp $
# By Greg J. Badros (C) 1994-1996
# gjb@cs.duke.edu, http://www.cs.duke.edu/~gjb
# Distribute freely as long as credit is given.
#
# You may use this file as specified under the GNU
# public license (GPL).
# I am not responsible for this file's use, misuse, or anything.
# Use at your own risk.
#
# This file needs to be pre-processed w/ m4, and its output
# is your real .zshrc file.  This is much faster than parsing
# the whole file, with includes and all, each time you want
# to start an iteractive shell (every time you open an xterm)
#
# See my <gjb@cs.duke.edu> makefile and update-config scripts

ulimit -c 5000

changequote([[[[,]]]])
notify=TRUE

ifdef([[[[GEAR_WRITABLE_CD]]]],[[[[
  PATH=${PATH}:/usr/gear
  export GEARDIR=/home/gjb
]]]])

# Only set display if we're not on a console
# (later we're going to set the TERM variable, so check this
#  first)
if [[ "$TERM" != "linux" && "$TERM" != "console" ]]; then
    echo "DISPLAY was $DISPLAY"
    export DISPLAY=${DISPLAY:-`who am i | sed -e 's/[^(]*(*//' -e 's/).*//'`}
 
    if [ "$DISPLAY" = "" ]; then
	export DISPLAY="$HOST:0.0"
    else
	export DISPLAY=${DISPLAY%%:0.0}:0.0
    fi
    echo "DISPLAY is $DISPLAY"
else
    # These beeps can get annoying if they're not visual
    setopt NO_LIST_BEEP
    setopt NO_HIST_BEEP
fi

alias unsetenv=unset
alias zh=zshelp
function setenv () { export $1="$2" }
function touser { cd ~$1/PWD }
function goto() { cd `which $1 | sed 's/\(\/.*\/\).*$/\1/'`;}
function killname() { kill `ps -Op -h | awk '/$1/ && !/awk/ {print $2}'`;}
function newtitle() { echo "]2;$1";}
function newicon() { echo "]1;$1";}

#FIGNORE=".o:,v"
unset noclobber
LESS='-MM -X'


# Someone had problems using 'eval tset' instead of 'TERM=',
# but you might want to try it anyway... with the right /etc/termcap it
# might work great.
# eval `tset -sQ "$TERM"`

if [ "$TERM" = "" -o "$TERM" = "unknown" -o \
     "`echo $TERM | cut -b1-3`" = "con" -o "$TERM" = "linux" ]; then
 TERM=vt100
fi

export TERMCAP=''

#Use eval `dircolors -[abbrev for shell]` instead of this
#(see /etc/profile)
#if [ "$TERM" = "xterm" -o "$TERM" = "color_xterm" ]; then
#  alias ls='color_ls --8bit --color=tty -F'
#fi
# A double pound eval means execute the command at config time,
# and substitue in place

#FIX: this should be done in advance
eval `dircolors -z`

# need below in case ls is just plain ls-- under linux,
# color_ls can just be a symlink to /bin/ls, but on solaris they're
# two binaries
ifdef([[[[SOLARIS]]]],[[[[
alias ls='color_ls $LS_OPTIONS'
]]]])

# this must come after ls is aliased to  color_ls , above
function z() { if [ ! "$1" = "" ]; then cd $1; fi; ls }

# PSVAR gets appended to the hostname in the window/icon title
PSVAR=" "
#Simple prompt
#PS1='%B%m:%~%# '
# Some more advanced possibilties for PS1
# %l is the tty line,
# %(6c,...%5c,%~) is an ternary-if-else to show only the last
#  five components of the path if it's over 6 components
# %0v means item 0 from PSVAR, a colon-separated list of strings
# ESC ]0;whatever sets the window title
# 
#PS1='%B%m,%l:%(6c,...%5c,%~)%#%b '
PS1='%B%m,%l:%(6c,...%5c,%~)%#%b '
if [ "$TERM" = "xterm" -o "$TERM" = "color_xterm" ]; then
  PS1='%{]0;%m %0v%}'$PS1
  # POSTPROMPT variable requires a patch by <gjb@cs.duke.edu>
  POSTPROMPT='%{]0;%H%}'
fi

ignoreeof=10

unsetopt MENU_COMPLETE
unsetopt BGNICE

#Don't count slashes as part of words
export WORDCHARS=${WORDCHARS:s%/%%}

#Let's '' be single quote like 'can''t' = "can't"
setopt RC_QUOTES
setopt LIST_TYPES
setopt AUTO_PUSHD
setopt PUSHD_IGNORE_DUPS
setopt PUSHD_TO_HOME
setopt PUSHD_SILENT
setopt PROMPT_SUBST
setopt AUTO_LIST
setopt AUTO_MENU
setopt IGNORE_EOF
setopt APPEND_HISTORY
setopt EXTENDED_HISTORY
setopt EXTENDED_GLOB
setopt HIST_IGNORE_SPACE
setopt HIST_IGNORE_DUPS
setopt HIST_NO_STORE
setopt HIST_LIT
setopt INTERACTIVE_COMMENTS
LITHISTSIZE=500
setopt NOTIFY
#SAVEHIST=500
setenv HISTFILE ~/private/.zsh-history
HISTSIZE=300
#don't export or setenv watch-- doesn't seem to work, and
# doesn't make sense, anyway.  don't want to watch on a local
# machine
#watch=(notme)

setenv REPORTTIME 30


include(.aliases)
include(.zshrc-zle)
include(.zshrc-compctl)
